#!/bin/sh

# script to run update, setting properties, for all projects


function usage() {
    printf "\n\tUsage: %s [-h] | [-v] [-c] -s stream -b buildrepositorypath"  $(basename $0) >&2
    printf "\n\t\t%s\n\n" "where h==help, v==verbose, c==clean and s==stream, where steam is Helios, Galileo, Ganymede, etc., " >&2
    printf "\n\t\t%s\n\n" "   and b is absolute path to directory of update site repository " >&2
     
}


clean=
stream=
verbose=
while getopts 'hvcs:b:' OPTION
do
    case $OPTION in
        h)    usage
        exit 1
        ;;
        c)    export clean=1
        ;;
        v)    export verbose=1
        ;;
        s)    stream=$OPTARG
        ;;     
        b)    export buildrepositorypath=$OPTARG
        ;;   
        ?)    usage
        exit 2
        ;;
    esac
done

shift $(($OPTIND - 1))

if [ -z $stream ]
then
  echo ""
  echo "    Need a stream argument"
  usage
  exit 1
fi 

echo "     Stream: " $stream

if [ -z $BUILD_INITIALIZED ]
then
  source properties.shsource
  source parseSiteArg.shsource $stream
  export BUILD_INITIALIZED=1
fi


if [ $clean ] ; then

	 echo "   Removing ${testUpdateSite}/features/"
	 rm -fr ${testUpdateSite}/features/
	
	 echo "   Removing ${testUpdateSite}/plugins/"
	 rm -fr ${testUpdateSite}/plugins/
	
	 echo "   Removing index and site xml files"
	 rm -fr ${testUpdateSite}/*

fi
	
echo "   Updating index and web site files, and site.xml file"
rsync -vrp "${buildrepositorypath}"/* "${testUpdateSite}"
rsync -vp ${HOME}/${updateToolsDir}/WebContent/${mainIndexFileName} ${testUpdateSite}/index.html
rsync -vp ${HOME}/${updateToolsDir}/WebContent/*.jpg ${testUpdateSite}

echo "add capabilities to site"

CAP_BUILD=20090608042922/S-S20090608042922-20090608042922

rsync -vrp /shared/webtools/committers/wtpcap-R3.1-S/"${CAP_BUILD}"/updateSite/features/* "${testUpdateSite}"/features/
rsync -vrp /shared/webtools/committers/wtpcap-R3.1-S/"${CAP_BUILD}"/updateSite/plugins/* "${testUpdateSite}"/plugins/


echo "add jaxws to site" 

JAXWS_BUILD=I-I20090813210640-20090813210640

rsync -vrp "${HOME}"/downloads/webtools/downloads/drops/R0.5/"${JAXWS_BUILD}"/updateSite/features/* "${testUpdateSite}"/features/
rsync -vrp "${HOME}"/downloads/webtools/downloads/drops/R0.5/"${JAXWS_BUILD}"/updateSite/plugins/* "${testUpdateSite}"/plugins/


./createMirrorFile.sh -s "$stream" -b "${testUpdateSite}"

if [ "$?" -ne 0 ] 
then 
   exit $?
fi  

# re-create P2 repository metadata
./ant.sh  -f createP2Repo.xml  -Declipse.home=${eclipseLocation} -Dupdate.site=${testUpdateSite}  

